# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector_v2.api.external_system_user_api import ExternalSystemUserApi


class TestExternalSystemUserApi(unittest.IsolatedAsyncioTestCase):
    """ExternalSystemUserApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ExternalSystemUserApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_external_system_user_external_system_user_get(self) -> None:
        """Test case for external_system_user_external_system_user_get

        External System User Get
        """
        pass

    async def test_external_system_user_external_system_user_update(self) -> None:
        """Test case for external_system_user_external_system_user_update

        External System User Update
        """
        pass

    async def test_external_system_user_get_user_by_external_system_info(self) -> None:
        """Test case for external_system_user_get_user_by_external_system_info

        Get User By External System Info
        """
        pass

    async def test_external_system_user_handle_message_from_external_system(self) -> None:
        """Test case for external_system_user_handle_message_from_external_system

        Handle Message From External System
        """
        pass


if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from chat_server_connector_v2.api.admin_api import AdminApi
from chat_server_connector_v2.api.bots_api import BotsApi
from chat_server_connector_v2.api.chat_api_api import ChatApiApi
from chat_server_connector_v2.api.chat_sessions_api import ChatSessionsApi
from chat_server_connector_v2.api.chat_settings_api import ChatSettingsApi
from chat_server_connector_v2.api.chats_api import ChatsApi
from chat_server_connector_v2.api.chats_v2_api import ChatsV2Api
from chat_server_connector_v2.api.contacts_api import ContactsApi
from chat_server_connector_v2.api.default_api import DefaultApi
from chat_server_connector_v2.api.external_system_user_api import ExternalSystemUserApi
from chat_server_connector_v2.api.feedback_api import FeedbackApi




# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector_v2.models.response_wrapper_list_contact import ResponseWrapperListContact

class TestResponseWrapperListContact(unittest.TestCase):
    """ResponseWrapperListContact unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperListContact:
        """Test ResponseWrapperListContact
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperListContact`
        """
        model = ResponseWrapperListContact()
        if include_optional:
            return ResponseWrapperListContact(
                done = True,
                result = [
                    chat_server_connector_v2.models.contact.Contact(
                        id = 56, 
                        role = 1, 
                        nickname = '', 
                        personal_description = '', 
                        first_name = '', 
                        last_name = '', 
                        avatar_id = '', 
                        is_online = True, 
                        address = null, 
                        phone_number = '', 
                        is_public_email = True, 
                        is_public_phone_number = True, 
                        is_public_city = True, 
                        is_public_country = True, 
                        email = '', )
                    ],
                error = ''
            )
        else:
            return ResponseWrapperListContact(
                done = True,
        )
        """

    def testResponseWrapperListContact(self):
        """Test ResponseWrapperListContact"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
